---
title: 'mod\_saslauth'
abstract: Handles authentication of users and remote servers.
---

Handles authentication of users and remote servers.

# Details

mod\_saslauth implements the standard SASL protocol according to the
guidelines in [RFC6120](http://xmpp.org/rfcs/rfc6120.html#sasl).

# Usage

``` {.code .lua}
    modules_enabled = {
        -- Other modules
        "saslauth"; -- Enable mod_saslauth
    }
```

# Configuration

  Option                            Default                Notes
  --------------------------------- ---------------------- ---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
  c2s\_require\_encryption          false                  Whether to force all client-to-server streams are encrypted before allowing authentication
  require\_encryption               false                  DEPRECATED - Currently used as a fallback value, recommended to use c2s\_require\_encryption
  anonymous\_login                  false                  DEPRECATED - See [Configuring anonymous logins](/doc/anonymous_logins) - If set to true, anonymous users will be allowed to login in and authentication disabled. This also disables server-to-server communication
  allow\_unencrypted\_plain\_auth   false                  Whether to allow plain-text passwords to be sent over the network
  insecure\_sasl\_mechanisms        `{"PLAIN", "LOGIN"}`   Mechanisms that are not allowed on unencrypted connections. Defaults to the empty set if allow\_unencrypted\_plain\_auth is set to true.
  disable\_sasl\_mechanisms         `{"DIGEST-MD5"}`       Set of mechanisms that will never be offered.

## Cyrus SASL integration {#cyrus_sasl_integration}

Documentation for this integration is available on our [Cyrus SASL
documentation page](/doc/cyrus_sasl).

# Example

``` {.code .lua}
    modules_enabled = {
        -- Other modules
        "saslauth"; -- Enable mod_saslauth
    }
 
    c2s_require_encryption = true
    allow_unencrypted_plain_auth = false
    disable_sasl_mechanisms = { "DIGEST-MD5" }
```
