---
title: 'mod\_watchregistrations'
---

If you run a server on which registration is open, it is quite likely
that you will want to know when someone registers a new account. This
module allows you to do just that.

# Details

By [enabling](/doc/modules_enabled) this module all [configured
admins](/doc/admins) will receive a message when someone registers. You
can customise this behaviour using the below options.

# Usage

``` {.code .lua}
    modules_enabled = {
        -- Other modules
        "watchregistrations"; -- Enable mod_watchregistrations
    }
```

# Configuration

  Option                       Default                                                   Notes
  ---------------------------- --------------------------------------------------------- -----------------------------------------------------------------------------------------------
  registration\_watchers       { }                                                       List of users to receive registration alerts, if empty the [admins](/doc/admins) list is used
  registration\_notification   \"User \$username just registered on \$host from \$ip\"   The message to send whenever a new user registers with variable expansion - see below

## Registration Notification Variables {#registration_notification_variables}

Some variables can be specified in registration\_notification and
Prosody will automatically replace them with the relevant information
before sending the message. The following list assumes a user has
registered new.user\@example.net from IP address 127.0.0.1.

  Variable     Description                                     Example
  ------------ ----------------------------------------------- -------------
  \$username   The username of the new user                    new.user
  \$host       The host of the new user                        example.net
  \$ip         The IP address the registration was made from   127.0.0.1

# Example

``` {.code .lua}
    modules_enabled = {
        -- Other modules
        "watchregistrations"; -- Enable mod_watchregistrations
    }
 
    registration_watchers = { "some.user@example.net" } -- mod_watchregistrations will use this list of users instead of the admin list
    registration_notification = "User $username just registered on $host from $ip"
```
