---
title: mod\_websocket
---

[WebSockets](http://en.wikipedia.org/wiki/WebSocket) is a protocol for
providing web pages with simple two-way communication with a web server.
This module allows browsers to communicate with Prosody via [XMPP over
WebSockets](https://www.rfc-editor.org/rfc/rfc7395.html). This usually
induces less overhead than using [BOSH](/doc/modules/mod_bosh).

There are many JavaScript XMPP libraries capable of utilizing
WebSockets, among them:

-   [stanza.io](https://github.com/legastero/stanza.io)
-   [strophe.js \>= 1.2.0](https://github.com/strophe/strophejs)
-   [Lightstring](https://github.com/sonnyp/lightstring)

# Usage

``` {.code .lua}
modules_enabled = {
    -- Other modules
    "websocket"; -- Enable mod_websocket
}
```

To allow requests that would normally break the Same-Origin policy, the
`cross_domain_websocket` option can be used. Set it to `true` to enable
cross-domain requests from all websites, or specify a list:

``` {.code .lua}
cross_domain_websocket = { "http://jabber.org", "http://prosody.im" }
```

If encryption is provided by a HTTP proxy, Prosody won't be able to see
this, and consider the connection insecure (consequently forbidding some
authentication mechanisms). In this case Prosody can be told to always
consider WebSocket connections secure by setting in the [global
section](/doc/configure#overview).

``` {.code .lua}
consider_websocket_secure = true
```

The WebSocket endpoint will be at `wss:example.com:5281/xmpp-websocket`
and `ws:example.com:5280/xmpp-websocket` by default, see [HTTP path
configuration](/doc/http#path_configuration) if you would like to change
this.

# Configuration

  Option                        Type      Default
  ----------------------------- --------- ---------------------------------
  `c2s_close_timeout`           number    `5`
  `consider_websocket_secure`   boolean   *empty*
  `cross_domain_websocket`      set       `{ "https://example.com" }`[^1]

[^1]: Uses the `http_host` setting on the current VirtualHost
