---
title: Prosody package repository
---

We now have a repository of Prosody packages to allow for automatic
updates using a package manager.

If you are using Debian, Ubuntu, or another derived GNU/Linux
distribution that uses APT (apt, aptitude, etc.) then you can do the
following:

# Debian 11+ {#debian}

On Debian 11 and later (or Debian 10 with
[backports](https://backports.debian.org/) enabled) our repository can
be enabled using extrepo like this:

``` bash
sudo apt install extrepo
sudo extrepo enable prosody
sudo apt update
```

Then to install the Prosody package simply run:

``` bash
sudo apt install prosody
```


# Other Debian based (e.g. Ubuntu) {#other}

For these systems the package manager needs a line of information about
where to find the repository. For Prosody's repository, this line is:

    deb https://packages.prosody.im/debian VERSION main

You need to replace `VERSION` with the version of your distribution you
are using. We currently support:

  Distribution       `VERSION`    Alias
  ------------------ ------------ -------------
  Debian 10          `buster`     `oldstable`
  Debian 11          `bullseye`   `stable`
  Debian unstable    `sid`        `unstable`
  Ubuntu 18.04 LTS   `bionic`     
  Ubuntu 20.04 LTS   `focal`      
  Ubuntu 21.10       `impish`     
  Ubuntu 22.04 LTS   `jammy`      

The set of supported Debian and Ubuntu versions follow what Debian and
Ubuntu support. You can find out which by running
`distro-info --supported`{.bash}.

If you are unsure which version your server is running, run the
following command in a terminal:

``` bash
lsb_release -sc
```

For other Debian or Ubuntu based distributions try to find out which
version of Ubuntu or Debian it was based on and use that, otherwise you
might need to experiment some.

## Architectures

We currently build packages for these architectures:

`amd64`
:   Most modern machines.

`i386`
:   Older 32-bit machines. [^1]

`arm64`
:   Newer 64-bit Raspberry Pi and similar.

`armhf`
:   32-bit Raspberry Pi and similar.

You can check if this matches your machine by running
`dpkg --print-architecture`{.bash}.

## Terminal

If you run one of the supported Ubuntu or Debian versions (see above),
you can coy this line (select it, right-click, and choose Copy):

``` bash
echo deb http://packages.prosody.im/debian $(lsb_release -sc) main | sudo tee -a /etc/apt/sources.list
```

Now switch to your terminal and paste it (usually right-click→Paste or
Ctrl+Shift+V).

Press enter, and enter your password if prompted.

Before you run apt update, you should import our key file, see the
next section.

### Adding our key file {#adding_our_key_file}

In order to prevent warnings about unauthenticated packages, you can add
our key file using the below command:

``` bash
wget https://prosody.im/files/prosody-debian-packages.key -O- | sudo apt-key add -
```

Finally to have APT find our packages, run:

``` bash
sudo apt update
```

Then to install the Prosody package simply run:

``` bash
sudo apt install prosody
```

## Graphical

Click 'System', then 'Administration'. Select 'Software Sources'.

Switch to the 'Third-party Software' tab. Click on the 'Add' button.

Into the box that opens, paste the line shown above beginning with
'deb'.

Click 'Add Source' to close the dialog, and click 'Reload' if prompted.

You should now be able to install the 'prosody' package using
[Synaptic](https://help.ubuntu.com/community/SynapticHowto#Browsing%20the%20package%20database).

### Adding our key file {#adding_our_key_file1}

Your system may warn you that the Prosody repository is not
authenticated, or untrusted. To fix this you need to give it our key
file.

Right-click on the link below and choose "Save Link As...". Save the
file to your desktop or home folder.

[Prosody packages
key](https://prosody.im/files/prosody-debian-packages.key).

Now back in the Software Sources manager, switch to the "Authentication"
tab. Click on the "Import Key File" button. Select our key file you just
downloaded, and click OK.

[^1]: The latest Ubuntu releases no longer support `i386` and we are
    unable to build packages for this target anymore.
